@@ -165,15 +165,14 @@ WidgetFactory.getKey = function(group, obj) {
     }
 
     var g = group;
-    if (typeof(obj["SettingsGroup"])!="undefined") {
-        g = obj["SettingsGroup"];
+    if (typeof(obj.property("SettingsGroup"))!="undefined") {
+        g = obj.property("SettingsGroup");
     }
     var key = [g, obj.objectName];
 
     // correct key:
     if (isOfType(obj, QRadioButton) || isOfType(obj, QToolButton)) {
         // correct to button group name:
-
         if (isFunction(obj.group) && !isNull(obj.group())) {
             key = [g, obj.group().objectName];
         }
@@ -518,7 +517,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             value = c.property("defaultValue");
         } else {
             if (!isNull(map)) {
-                value = map.get(key);                
+                value = map.get(key);
             } else {
                 if (!isNull(document)) {
                     if (isObject(document)) {
@@ -706,7 +705,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 WidgetFactory.connect(c.toggled, signalReceiver, c.objectName);
                 WidgetFactory.connect(c.toggled, WidgetFactory.topLevelWidget, "Setting");
                 if (value==="true") {
-                    c.checked = value;
+                    c.checked = true;
                 }
                 else {
                     c.checked = (c.objectName == value);
@@ -1282,7 +1281,7 @@ WidgetFactory.initLineEdit = function(lineEdit, dimension) {
         menu.insertMenu(separatorAction, subMenu);
         menu.exec(QCursor.pos());
         if (!isDeleted(menu)) {
-            menu.destroy();
+            destr(menu);
         }
     });
 };
